@@ -1,5 +1,7 @@
 from .rival import rival
+from .rival95 import rival95
 from .rival100 import rival100
+from .rival105 import rival105
 from .rival100dota2edition import rival100dota2edition
 from .rival110 import rival110
 from .rival300 import rival300
@@ -13,11 +15,14 @@ from .rival500 import rival500
 from .rival600 import rival600
 from .rival710 import rival710
 from .hotssenseiraw import hotssenseiraw
+from .sensei310 import sensei310
 from .kanav2 import kanav2
 
 mice_profiles = [
     rival,
+    rival95,
     rival100,
+    rival105,
     rival100dota2edition,
     rival110,
     rival300,
@@ -31,5 +36,6 @@ mice_profiles = [
     rival600,
     rival710,
     hotssenseiraw,
+    sensei310,
     kanav2,
 ]
